@@ -171,11 +171,11 @@ XML::GSA - Creates xml in google search appliance (GSA) format
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 SYNOPSIS
 
@@ -209,8 +209,20 @@ Which will output:
 
     <?xml version="1.0" encoding="UTF-8"?>
     <!DOCTYPE gsafeed PUBLIC "-//Google//DTD GSA Feeds//EN" "">
-    <gsafeed><header><datasource>Source</datasource><feedtype>incremental</feedtype></header><group action="add"><record action="delete" url="http://www.foo.bar/aaa" mimetype="text/plain"></record><record url="http://www.foo.bar/bbb" mimetype="text/plain"><metadata><meta content="BBB" name="og:title"></meta></metadata></record></group></gsafeed>
-
+    <gsafeed>
+        <header>
+            <datasource>Source</datasource>
+            <feedtype>incremental</feedtype>
+        </header>
+        <group action="add">
+            <record action="delete" url="http://www.foo.bar/aaa" mimetype="text/plain"></record>
+            <record url="http://www.foo.bar/bbb" mimetype="text/plain">
+                <metadata>
+                    <meta content="BBB" name="og:title"></meta>
+                </metadata>
+            </record>
+        </group>
+    </gsafeed>
 
 =head1 METHODS
 
